@@ -40,6 +40,7 @@ def DATEVALUE(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "DATEVALUE",
         "description": "Converts a given string to a date series.",
+        "search_terms": ["datevalue", "date value", "date", "string to date", "datetime", "dtype", "convert"],
         "examples": [
             "DATEVALUE(date_column)",
             "DATEVALUE('2012-12-22')"
@@ -68,6 +69,7 @@ def DAY(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "DAY",
         "description": "Returns the day of the month that a specific date falls on, as a number.",
+        "search_terms": ["day", "date"],
         "examples": [
             "DAY(date_column)",
             "DAY('2012-12-22')"
@@ -96,6 +98,7 @@ def ENDOFBUSINESSMONTH(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "ENDOFBUSINESSMONTH",
         "description": "Given a date, returns the end of the buisness month. E.g. the last weekday.",
+        "search_terms": ["business", "month", "eom", "eobm", "date", "workday", "end"],
         "examples": [
             "ENDOFBUSINESSMONTH(date_column)",
             "ENDOFBUSINESSMONTH('2012-12-22')"
@@ -124,6 +127,7 @@ def ENDOFMONTH(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "ENDOFMONTH",
         "description": "Given a date, returns the end of the month, as a date. E.g. input of 12-22-1997 will return 12-31-1997.",
+        "search_terms": ["month", "eom", "date", "workday", "end", "eomonth"],
         "examples": [
             "ENDOFMONTH(date_column)",
             "ENDOFMONTH('2012-12-22')"
@@ -152,6 +156,7 @@ def HOUR(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "HOUR",
         "description": "Returns the hour component of a specific date, as a number.",
+        "search_terms": ["hour", "hr"],
         "examples": [
             "HOUR(date_column)",
             "HOUR('2012-12-22 09:45:00')"
@@ -180,6 +185,7 @@ def MINUTE(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "MINUTE",
         "description": "Returns the minute component of a specific date, as a number.",
+        "search_terms": ["minute", "min"],
         "examples": [
             "MINUTE(date_column)",
             "MINUTE('2012-12-22 09:45:00')"
@@ -208,6 +214,7 @@ def MONTH(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "MONTH",
         "description": "Returns the month that a specific date falls in, as a number.",
+        "search_terms": ["month", "date"],
         "examples": [
             "MONTH(date_column)",
             "MONTH('2012-12-22')"
@@ -236,6 +243,7 @@ def QUARTER(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "QUARTER",
         "description": "Returns the quarter (1-4) that a specific date falls in, as a number.",
+        "search_terms": ["quarter"],
         "examples": [
             "QUARTER(date_column)",
             "QUARTER('2012-12-22')"
@@ -264,6 +272,7 @@ def STARTOFBUSINESSMONTH(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STARTOFBUSINESSMONTH",
         "description": "Given a date, returns the most recent start of the business month, as a state. E.g. the first weekday.",
+        "search_terms": ["business", "month", "SOM", "SOBM", "date", "start"],
         "examples": [
             "STARTOFBUSINESSMONTH(date_column)",
             "STARTOFBUSINESSMONTH('2012-12-22 09:23:05')"
@@ -292,6 +301,7 @@ def STARTOFMONTH(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STARTOFMONTH",
         "description": "Given a date, returns the start of the month, as a date. E.g. input of 12-22-1997 will return 12-1-1997.",
+        "search_terms": ["month", "SOM", "date", "start"],
         "examples": [
             "STARTOFMONTH(date_column)",
             "STARTOFMONTH('2012-12-22 09:23:05')"
@@ -321,6 +331,7 @@ def STRIPTIMETOMINUTES(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STRIPTIMETOMINUTES",
         "description": "Returns the date with a seconds component of 00.",
+        "search_terms": ["time", "date", "minutes", "strip"],
         "examples": [
             "STRIPTIMETOMINUTES(date_column)",
             "STRIPTIMETOMINUTES('2012-12-22 09:23:05')"
@@ -349,6 +360,7 @@ def STRIPTIMETOHOURS(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STRIPTIMETOHOURS",
         "description": "Returns the date with a seconds and minutes component of 00:00.",
+        "search_terms": ["time", "date", "hours", "strip"],
         "examples": [
             "STRIPTIMETOHOURS(date_column)",
             "STRIPTIMETOHOURS('2012-12-22 09:23:05')"
@@ -378,6 +390,7 @@ def STRIPTIMETODAYS(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STRIPTIMETODAYS",
         "description": "Returns the date with a seconds, minutes, and hours component of 00:00:00.",
+        "search_terms": ["time", "date", "days", "strip"],
         "examples": [
             "STRIPTIMETODAYS(date_column)",
             "STRIPTIMETODAYS('2012-12-22 09:23:05')"
@@ -406,6 +419,7 @@ def STRIPTIMETOMONTHS(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STRIPTIMETOMONTHS",
         "description": "Returns the date adjusted to the start of the month.",
+        "search_terms": ["time", "date", "months", "strip"],
         "examples": [
             "STRIPTIMETOMONTHS(date_column)",
             "STRIPTIMETOMONTHS('2012-12-22 09:23:05')"
@@ -435,6 +449,7 @@ def STRIPTIMETOYEARS(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "STRIPTIMETOYEARS",
         "description": "Returns the date adjusted to the start of the year.",
+        "search_terms": ["time", "date", "years", "strip"],
         "examples": [
             "STRIPTIMETOYEARS(date_column)",
             "STRIPTIMETOYEARS('2012-12-22 09:23:05')"
@@ -463,6 +478,7 @@ def SECOND(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "SECOND",
         "description": "Returns the seconds component of a specific date, as a number.",
+        "search_terms": ["second", "sec"],
         "examples": [
             "SECOND(date_column)",
             "SECOND('2012-12-22 09:23:05')"
@@ -491,6 +507,7 @@ def WEEK(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "WEEK",
         "description": "Returns the week (1-52) of a specific date, as a number.",
+        "search_terms": ["week", "1", "52"],
         "examples": [
             "WEEK(date_column)",
             "WEEK('2012-12-22 09:23:05')"
@@ -519,6 +536,7 @@ def WEEKDAY(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "WEEKDAY",
         "description": "Returns the day of the week that a specific date falls on. 1-7 corresponds to Monday-Sunday.",
+        "search_terms": ["weekday", "monday", "tuesday", "wednesday", "thursday", "friday", "saturday", "sunday"],
         "examples": [
             "WEEKDAY(date_column)",
             "WEEKDAY('2012-12-22')"
@@ -547,6 +565,7 @@ def YEAR(datetime_series: pd.Series) -> pd.Series:
     {
         "function": "YEAR",
         "description": "Returns the day of the year that a specific date falls in, as a number.",
+        "search_terms": ["year", "date"],
         "examples": [
             "YEAR(date_column)",
             "YEAR('2012-12-22')"
