@@ -9,7 +9,7 @@ from typing import Any, Collection, List, Dict, Optional, Set
 import pandas as pd
 
 from mitosheet.column_headers import ColumnIDMap
-from mitosheet.types import ColumnID
+from mitosheet.types import ColumnHeader, ColumnID
 from mitosheet.utils import get_first_unused_dataframe_name
 
 # Constants for where the dataframe in the state came from
@@ -19,6 +19,8 @@ DATAFRAME_SOURCE_PIVOTED = "pivoted"  # created through a pivot
 DATAFRAME_SOURCE_MERGED = "merged"  # created through a merge
 DATAFRAME_SOURCE_CONCAT = "concated"  # created through a concat
 DATAFRAME_SOURCE_DUPLICATED = "duplicated"  # created through a sheet duplication
+DATAFRAME_SOURCE_TRANSPOSED = "transposed"  # created through a dataframe being transposed
+DATAFRAME_SOURCE_MELTED = "melted"  # created through a dataframe being melted
 
 # Constants used for formatting. Defined here to avoid circular imports
 FORMAT_DEFAULT = "default"
@@ -133,7 +135,7 @@ class State:
             deep_sheet_indexes = []
         
         return State(
-            [df.copy(deep=True) if index in deep_sheet_indexes else df.copy(deep=False) for index, df in enumerate(self.dfs)],
+            [df.copy(deep=index in deep_sheet_indexes) for index, df in enumerate(self.dfs)],
             df_names=deepcopy(self.df_names),
             df_sources=deepcopy(self.df_sources),
             column_ids=deepcopy(self.column_ids),
@@ -233,6 +235,18 @@ class State:
             # Return the index of this sheet
             return sheet_index
 
+    def add_columns_to_state(self, sheet_index: int, column_headers: List[ColumnHeader]) -> None:
+        """
+        Helper function for adding a new columns to this state, making sure that we 
+        track the relevant metadata variables.
+        """
+        # Update column state variables
+        for column_header in column_headers:
+            column_id = self.column_ids.add_column_header(sheet_index, column_header)
+            self.column_spreadsheet_code[sheet_index][column_id] = ''
+            self.column_filters[sheet_index][column_id] = {'operator': 'And', 'filters': []}
+            self.column_format_types[sheet_index][column_id] = {'type': FORMAT_DEFAULT}
+
     def does_sheet_index_exist_within_state(self, sheet_index: int) -> bool:
         """
         Returns true iff a sheet_index exists within this state
