@@ -4,9 +4,11 @@
 # Copyright (c) Saga Inc.
 # Distributed under the terms of the GPL License.
 
-from typing import Dict, List, Optional, Any
+from typing import Dict, List, Optional, Any, Union
+from mitosheet.state import State
 import io
-
+from xmlrpc.client import boolean
+from mitosheet.transpiler.transpile_utils import column_header_to_transpiled_code
 
 from mitosheet.types import ColumnHeader
 import plotly.graph_objects as go
@@ -37,30 +39,60 @@ GRAPH_TITLE_LABELS = {
     DENSITY_CONTOUR: "density contour",
 }
 
+# TAB is used in place of \t in generated code because
+# Jupyter turns \t into a grey arrow, but converts four spaces into a tab.
+TAB = "    "
 
-def get_barmode(graph_type: str) -> Optional[str]:
+def param_dict_to_code(param_dict: Dict[str, Any], level: int=0, as_single_line: boolean=False) -> str:
     """
-    Helper function for determing the barmode to apply to the graph creation function, depending
-    on the type of graph being created
+    Takes a potentially nested params dictonary and turns it into a
+    code string that we can use in the graph generated code.
+
+    level should be 0 if we are at the highest level dict, and otherwise
+    should increment by 1 anytime we enter a new subdictonary.
     """
-    if graph_type == BOX:
-        return "stack"
-    elif graph_type == HISTOGRAM:
-        return "group"
-    elif graph_type == BAR:
-        return "group"
+
+    # Make sure we handle as a single line properly
+    if as_single_line:
+        TAB_CONSTANT = ''
+        NEWLINE_CONSTANT = ''
     else:
-        return None
+        TAB_CONSTANT = TAB
+        NEWLINE_CONSTANT = '\n'
 
-
-def create_parameter(param_key: str, param_value: str, format_as_string: bool) -> str:
-    """
-    Returns the params ready to be used in the transpiled code.
-    """
-    if format_as_string:
-        return f"{param_key}='{param_value}'"
+    if level == 0:
+        code = f"{NEWLINE_CONSTANT}"
     else:
-        return f"{param_key}={param_value}"
+        code = f"dict({NEWLINE_CONSTANT}"
+
+    value_num = 0
+    for key, value in param_dict.items():
+        if isinstance(value, dict):
+            # Recurse on this nested param dictonary
+            code_chunk = f"{key} = {param_dict_to_code(value, level=level + 1)}"
+        else:
+            # We use this slighly misnamed function to make sure values get transpiled right
+            code_chunk = f"{key}={column_header_to_transpiled_code(value)}"
+        
+        # If we're not on the first value in this dict, we need to add a 
+        # command new line after the last value
+        if value_num != 0:
+            code += f", {NEWLINE_CONSTANT}"
+
+        value_num += 1
+
+        # Add spacing before the param
+        code += f"{TAB_CONSTANT * (level + 1)}"
+
+        code += f"{code_chunk}"
+
+    if level == 0:
+        code += f"{NEWLINE_CONSTANT}"
+    else:
+        # Make sure to close the dict
+        code += f"{NEWLINE_CONSTANT}{TAB_CONSTANT * (level)})"
+    
+    return code
 
 
 def get_graph_title(
@@ -151,3 +183,13 @@ def get_html_and_script_from_figure(
     script = split_html[1][: -len(script_end)]
 
     return {"html": div, "script": script}
+
+def get_column_header_from_optional_column_id_graph_param(
+    state: State, 
+    graph_creation_params: Dict[str, Any], 
+    param_name: str
+) -> Optional[ColumnHeader]:
+    sheet_index = graph_creation_params['sheet_index']
+    if param_name in graph_creation_params.keys() and graph_creation_params[param_name] in state.column_ids.column_id_to_column_header[sheet_index].keys():
+        return state.column_ids.get_column_header_by_id(sheet_index, graph_creation_params[param_name])
+    else: return None
\ No newline at end of file
