@@ -9,7 +9,7 @@ Replays an existing analysis
 
 from mitosheet.errors import make_no_analysis_error
 
-from mitosheet.mito_analytics import log
+from mitosheet.telemetry.telemetry_utils import log
 from mitosheet.saved_analyses import read_and_upgrade_analysis
 from mitosheet.types import StepsManagerType
 
@@ -49,6 +49,7 @@ def execute_replay_analysis_update(
     # to be played
     steps_manager.analysis_name = analysis_name
 
+
 REPLAY_ANALYSIS_UPDATE = {
     'event_type': REPLAY_ANALYSIS_UPDATE_EVENT,
     'params': REPLAY_ANALYSIS_UPDATE_PARAMS,
