@@ -31,13 +31,14 @@ the other.
 _Any change the user.json format must be met with a version bump._
 """
 from typing import Any, Dict
+from mitosheet.experiments.experiment_utils import get_current_experiment, get_new_experiment
 
 from mitosheet.user.db import get_user_json_object, set_user_json_object
-from mitosheet.user.schemas import (UJ_CLOSED_FEEDBACK, UJ_FEEDBACKS_V2,
+from mitosheet.user.schemas import (UJ_CLOSED_FEEDBACK, UJ_EXPERIMENT, UJ_FEEDBACKS_V2,
                                     UJ_INTENDED_BEHAVIOR,
                                     UJ_MITOSHEET_LAST_FIFTY_USAGES,
                                     UJ_MITOSHEET_LAST_FIVE_USAGES,
-                                    UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY,
+                                    UJ_MITOSHEET_PRO, UJ_MITOSHEET_TELEMETRY, UJ_RECEIVED_CHECKLISTS,
                                     UJ_USER_JSON_VERSION, USER_JSON_DEFAULT,
                                     USER_JSON_VERSION_1)
 
@@ -140,6 +141,46 @@ def upgrade_user_json_version_4_to_5(user_json_version_4: Dict[str, Any]) -> Dic
         user_json_version_4[UJ_MITOSHEET_PRO] = False
     return user_json_version_4
 
+def upgrade_user_json_version_5_to_6(user_json_version_5: Dict[str, Any]) -> Dict[str, Any]:
+    """
+    Just adds the UJ_EXPERIMENT field, and sets it equal to
+    the default expirments list
+    """
+    # First, bump the version number
+    user_json_version_5[UJ_USER_JSON_VERSION] = 6
+
+    # Then, set new field
+    if UJ_EXPERIMENT not in user_json_version_5:
+        user_json_version_5[UJ_EXPERIMENT] = get_new_experiment()
+
+    return user_json_version_5
+
+def upgrade_user_json_version_6_to_7(user_json_version_6: Dict[str, Any]) -> Dict[str, Any]:
+    """
+    Just adds the UJ_RECEIVED_CHECKLISTS field, and sets it equal to the full onboarding
+    checklist. This is because we do not want users to have to go back and do the onboarding
+    checklist if they are already onboarded.
+
+    We only upgrade them if they are not on the installer_communication_and_time_to_value 
+    experiment, as this means that they have used the installer, and we actually _want_
+    them to go through the onboarding checklist.
+    """
+    # First, bump the version number
+    user_json_version_6[UJ_USER_JSON_VERSION] = 7
+
+    # Then, set new field
+    if UJ_RECEIVED_CHECKLISTS not in user_json_version_6:
+        current_experiment = user_json_version_6[UJ_EXPERIMENT]
+        if current_experiment['experiment_id'] != 'installer_communication_and_time_to_value':
+            user_json_version_6[UJ_RECEIVED_CHECKLISTS] = {
+                "onboarding_checklist": ['signup', 'import', 'filter', 'pivot', 'graph', 'finalize']
+            }
+        else:
+            user_json_version_6[UJ_RECEIVED_CHECKLISTS] = {}
+
+
+    return user_json_version_6
+
 def try_upgrade_user_json_to_current_version() -> None:
     user_json_object = get_user_json_object()
 
@@ -163,6 +204,16 @@ def try_upgrade_user_json_to_current_version() -> None:
         user_json_object = upgrade_user_json_version_3_to_4(user_json_object)
     if user_json_object[UJ_USER_JSON_VERSION] == 4:
         user_json_object = upgrade_user_json_version_4_to_5(user_json_object)
+    if user_json_object[UJ_USER_JSON_VERSION] == 5:
+        user_json_object = upgrade_user_json_version_5_to_6(user_json_object)
+    if user_json_object[UJ_USER_JSON_VERSION] == 6:
+        user_json_object = upgrade_user_json_version_6_to_7(user_json_object)
+
+    # We always make sure that the experiment is the most up to date
+    # version of the experiment
+    new_experiment = get_new_experiment()
+    if new_experiment is not None and user_json_object[UJ_EXPERIMENT]['experiment_id'] != new_experiment['experiment_id']:
+            user_json_object[UJ_EXPERIMENT] = new_experiment
 
     set_user_json_object(user_json_object)
 
